<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:cfg="http://software.in2p3.fr/lavoisier/application.xsd"
                xmlns:lav="http://software.in2p3.fr/lavoisier/application.xsd"
                xmlns="http://software.in2p3.fr/lavoisier/application.xsd"
                exclude-result-prefixes="cfg lav">
    <xsl:output method="xml" omit-xml-declaration="yes"/>
    <xsl:variable name="VERSION">15</xsl:variable>

    <!-- expand namespaces -->
    <xsl:template match="lav:view | lav:view-template | lav:pre-renderers">
        <xsl:copy><xsl:copy-of select="@*"/>
            <!-- convert xmlns:ns to <namespace prefix="ns"/> -->
            <xsl:for-each select="(/* | ancestor::* | descendant-or-self::*)/namespace::*
                                        [name()!='']
                                        [.!='http://www.w3.org/XML/1998/namespace']">
                <namespace prefix="{name()}" uri="{.}"/>
            </xsl:for-each>
            <!-- recursive -->
            <xsl:apply-templates select="* | text() | comment()"/>
        </xsl:copy>
    </xsl:template>

    <!-- expand pixtl aggregation -->
    <xsl:template match="/">
        <xsl:for-each select="descendant::lav:parameter[contains(@eval,'post()')][ancestor::lav:insert | ancestor::lav:replace]">
            <xsl:message terminate="yes">Error in view '<xsl:value-of select="ancestor::lav:view/@name"/>':
                Function post() not allowed in elements insert and replace</xsl:message>
        </xsl:for-each>
        <!-- start -->
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="lav:view[(lav:processors/lav:insert | lav:processors/lav:replace)/lav:connector]">
        <xsl:for-each select="(descendant::lav:processors/lav:insert | descendant::lav:processors/lav:replace)[lav:connector]">
            <view>
                <xsl:attribute name="name">
                    <xsl:value-of select="ancestor::lav:view/@name"/>
                    <xsl:apply-templates select="ancestor-or-self::lav:*" mode="POSITION"/>
                </xsl:attribute>
                <xsl:copy-of select="ancestor::lav:view/@*[not(local-name()='name' or local-name()='post-processors')]"/>
                <xsl:copy-of select="ancestor::lav:view/lav:namespace"/>
                <info>
                    <category>Hidden</category>
                </info>
                <xsl:choose>
                    <xsl:when test="ancestor::lav:view/lav:argument">
                        <xsl:copy-of select="ancestor::lav:view/lav:argument"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <argument name="disable-default-XPath" path-format="value">true</argument>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:apply-templates select="*"/>
            </view>
        </xsl:for-each>
        <xsl:copy><xsl:copy-of select="@*"/>
            <xsl:apply-templates select="* | text() | comment()"/>
        </xsl:copy>
    </xsl:template>

    <xsl:template match="lav:processors/lav:*[(self::lav:insert | self::lav:replace)/lav:connector]">
        <xsl:copy><xsl:copy-of select="@*"/>
            <xsl:attribute name="nodes">
                <xsl:text>view_path_post('</xsl:text>
                <xsl:value-of select="ancestor::lav:view/@name"/>
                <xsl:apply-templates select="ancestor-or-self::lav:*" mode="POSITION"/>
                <xsl:text>', choose(path(false()), path(false()), ''), match(), arguments())</xsl:text>
            </xsl:attribute>
        </xsl:copy>
    </xsl:template>

    <xsl:template match="lav:processors/lav:*[(self::lav:insert | self::lav:replace)/lav:connector]" mode="POSITION">
        <xsl:text>_</xsl:text>
        <xsl:value-of select="count(preceding-sibling::lav:*[lav:connector])"/>
    </xsl:template>
    <xsl:template match="lav:*" mode="POSITION"/>

    <!-- common -->
    <xsl:template match="/cfg:config/@version">
        <xsl:attribute name="version">
            <xsl:value-of select="$VERSION"/>
        </xsl:attribute>
    </xsl:template>
    <xsl:template match="@* | comment()" priority="-1">
        <xsl:copy-of select="."/>
    </xsl:template>
    <xsl:template match="*" priority="-1">
        <xsl:copy><xsl:apply-templates select="@*"/>
            <xsl:apply-templates/>
        </xsl:copy>
    </xsl:template>
</xsl:stylesheet>